==> haskell-skylighting-core-0.8.2.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting-core
version: 0.8.2.3
id: skylighting-core-0.8.2.3-1Qophfeufh68boAEoCkKYm
key: skylighting-core-0.8.2.3-1Qophfeufh68boAEoCkKYm
license: BSD-3-Clause
copyright: (C) 2016-2018 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.
category: Text
abi: c4c2a2301b36e9173cb5a3073fdffe94
exposed: True
exposed-modules:
    Skylighting.Core Skylighting.Format.ANSI Skylighting.Format.HTML
    Skylighting.Format.LaTeX Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/skylighting-core-0.8.2.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/skylighting-core-0.8.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/skylighting-core-0.8.2.3
hs-libraries: HSskylighting-core-0.8.2.3-1Qophfeufh68boAEoCkKYm
depends:
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz binary-0.8.6.0
    blaze-html-0.9.1.2-HwoBmHvd8MidwTYIDsO4n bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    colour-2.3.5-y0xjV3ONUd40VuBtReEvC containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hxt-9.3.1.18-JVRjL39a79P6ewXCRFHG4l mtl-2.2.2
    regex-pcre-0.94.4-6OiTOSawdaJqgEwlhRSRS
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji text-1.2.3.1
    transformers-0.5.6.2 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock
haddock-html: /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-core-0.8.2-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting-core
version: 0.8.2
id: skylighting-core-0.8.2-IHa3uf4nMpY3Ycl5GvPLVm
key: skylighting-core-0.8.2-IHa3uf4nMpY3Ycl5GvPLVm
license: BSD-3-Clause
copyright: (C) 2016-2018 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.
category: Text
abi: 18801b1849205c00751accee2c6dfa44
exposed: True
exposed-modules:
    Skylighting.Core Skylighting.Format.ANSI Skylighting.Format.HTML
    Skylighting.Format.LaTeX Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/skylighting-core-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/skylighting-core-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/skylighting-core-0.8.2
hs-libraries: HSskylighting-core-0.8.2-IHa3uf4nMpY3Ycl5GvPLVm
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW
    ansi-terminal-0.9.1-7greAUREMxf1pgDTp3Pb1X
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    base64-bytestring-1.0.0.2-C0hiEzqCknwIpHHXqmcpJo binary-0.8.6.0
    blaze-html-0.9.1.1-Icge9VdFJKdIYmonGkJUKg bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    colour-2.3.5-KhGPW5qZVuqBSMjjUiJ91B containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hxt-9.3.1.18-JVRjL39a79P6ewXCRFHG4l mtl-2.2.2
    regex-pcre-0.94.4-6OiTOSawdaJqgEwlhRSRS
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji text-1.2.3.1
    transformers-0.5.6.2 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock
haddock-html: /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
